==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/SwatchColorPicker/SwatchColorPicker.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import _mergeJSXProps from '../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';
import { Grid } from '../../utilities/grid/Grid.js';
import '../../utilities/grid/GridCell.js';
import './ColorPickerGridCell/ColorPickerGridCell.base.js';
import { ColorPickerGridCell } from './ColorPickerGridCell/ColorPickerGridCell.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var SwatchColorPickerBase = function (_BaseComponent) {
  _inherits(SwatchColorPickerBase, _BaseComponent);

  var _super = _createSuper(SwatchColorPickerBase);

  function SwatchColorPickerBase() {
    _classCallCheck(this, SwatchColorPickerBase);

    return _super.apply(this, arguments);
  }

  _createClass(SwatchColorPickerBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var colorCells = this.colorCells,
          columnCount = this.columnCount,
          cellShape = this.cellShape,
          cellWidth = this.cellWidth,
          cellHeight = this.cellHeight;
      return h(Grid, _mergeJSXProps([{
        "attrs": {
          "items": colorCells,
          "column-count": columnCount
        }
      }, {
        scopedSlots: {
          "default": function _default(_ref) {
            var item = _ref.cell;
            return h(ColorPickerGridCell, {
              "attrs": {
                "color": item.color,
                "circle": cellShape === 'circle',
                "width": cellWidth,
                "height": cellHeight
              }
            });
          }
        }
      }]));
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          cellMargin = this.cellMargin;
      return getClassNames(styles, {
        theme: theme,
        className: className,
        cellMargin: cellMargin
      });
    }
  }]);

  return SwatchColorPickerBase;
}(BaseComponent);

__decorate([Prop({
  "default": 10
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellMargin", void 0);

__decorate([Prop({
  type: Array,
  "default": function _default() {
    return [];
  }
}), __metadata("design:type", Array)], SwatchColorPickerBase.prototype, "colorCells", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "columnCount", void 0);

__decorate([Prop({
  type: String,
  "default": 'circle'
}), __metadata("design:type", String)], SwatchColorPickerBase.prototype, "cellShape", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellHeight", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellWidth", void 0);

SwatchColorPickerBase = __decorate([Component({
  components: {
    Grid: Grid,
    ColorPickerGridCell: ColorPickerGridCell
  },
  inheritAttrs: false
})], SwatchColorPickerBase);

export { SwatchColorPickerBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/SwatchColorPicker/SwatchColorPicker.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.number.constructor';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { Grid } from '../../utilities/grid/Grid.js';
import '../../utilities/grid/GridCell.js';
import './ColorPickerGridCell/ColorPickerGridCell.base.js';
import { ColorPickerGridCell } from './ColorPickerGridCell/ColorPickerGridCell.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var SwatchColorPickerBase = function (_BaseComponent) {
  _inherits(SwatchColorPickerBase, _BaseComponent);

  var _super = _createSuper(SwatchColorPickerBase);

  function SwatchColorPickerBase() {
    _classCallCheck(this, SwatchColorPickerBase);

    return _super.apply(this, arguments);
  }

  _createClass(SwatchColorPickerBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var colorCells = this.colorCells,
          columnCount = this.columnCount,
          cellShape = this.cellShape,
          cellWidth = this.cellWidth,
          cellHeight = this.cellHeight;
      return h(Grid, _mergeJSXProps([{
        "attrs": {
          "items": colorCells,
          "column-count": columnCount
        }
      }, {
        scopedSlots: {
          default: function _default(_ref) {
            var item = _ref.cell;
            return h(ColorPickerGridCell, {
              "attrs": {
                "color": item.color,
                "circle": cellShape === 'circle',
                "width": cellWidth,
                "height": cellHeight
              }
            });
          }
        }
      }]));
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          cellMargin = this.cellMargin;
      return getClassNames(styles, {
        theme: theme,
        className: className,
        cellMargin: cellMargin
      });
    }
  }]);

  return SwatchColorPickerBase;
}(BaseComponent);

__decorate([Prop({
  default: 10
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellMargin", void 0);

__decorate([Prop({
  type: Array,
  default: function _default() {
    return [];
  }
}), __metadata("design:type", Array)], SwatchColorPickerBase.prototype, "colorCells", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "columnCount", void 0);

__decorate([Prop({
  type: String,
  default: 'circle'
}), __metadata("design:type", String)], SwatchColorPickerBase.prototype, "cellShape", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellHeight", void 0);

__decorate([Prop({
  type: Number
}), __metadata("design:type", Number)], SwatchColorPickerBase.prototype, "cellWidth", void 0);

SwatchColorPickerBase = __decorate([Component({
  components: {
    Grid: Grid,
    ColorPickerGridCell: ColorPickerGridCell
  },
  inheritAttrs: false
})], SwatchColorPickerBase);

export { SwatchColorPickerBase };
